@@ -4,23 +4,21 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch12/12.2/12.2.1/12.2.1-15-s.js
- * @description arguments - a function expr assigning into 'arguments' throws a SyntaxError in strict mode
+ * @path ch12/12.2/12.2.1/12.2.1-4-s.js
+ * @description eval - a function expr assigning into 'eval' throws a SyntaxError in strict mode
  * @onlyStrict
  */
 
 
-
-
 function testcase() {
   'use strict';
 
   try {
-    eval('(function () {arguments = 42;})()');
+    eval('(function () { eval = 42; })()');
     return false;
   }
   catch (e) {
     return (e instanceof SyntaxError);
   }
-}
-runTestCase(testcase);
\ No newline at end of file
+ }
+runTestCase(testcase);
