@@ -4,12 +4,16 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch15/15.5/15.5.4/15.5.4.20/15.5.4.20-2-37.js
- * @description String.prototype.trim - 'this' is a Number Object that converts to a string
+ * @path ch15/15.2/15.2.3/15.2.3.6/15.2.3.6-2-10.js
+ * @description Object.defineProperty - argument 'P' is a number that converts to a string (value is a negative number)
  */
 
 
 function testcase() {
-        return (String.prototype.trim.call(new Number(123)) === "123");
+        var obj = {};
+        Object.defineProperty(obj, -20, {});
+
+        return obj.hasOwnProperty("-20");
+
     }
 runTestCase(testcase);
