@@ -4,18 +4,20 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch15/15.3/15.3.5/15.3.5.4/15.3.5.4_2-49gs.js
- * @description Strict mode - checking access to strict function caller from non-strict function (Literal getter includes strict directive prologue)
- * @noStrict
+ * @path ch15/15.3/15.3.5/15.3.5.4/15.3.5.4_2-52gs.js
+ * @description Strict mode - checking access to strict function caller from strict function (Injected getter defined within strict mode)
+ * @onlyStrict
  * @negative TypeError
  */
 
 
-var o = { get foo() { "use strict"; return gNonStrict(); } }
+"use strict";
+var o = {};
+Object.defineProperty(o, "foo",  { get: function() { return gNonStrict(); } });
 o.foo;
 
 
 function gNonStrict() {
-    return gNonStrict.caller || gNonStrict.caller.throwTypeError;
+    return gNonStrict.caller;
 }
 
