@@ -4,22 +4,19 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch15/15.4/15.4.4/15.4.4.16/15.4.4.16-7-c-ii-18.js
- * @description Array.prototype.every - 'this' of 'callbackfn' is an String object when T is not an object (T is a string primitive)
+ * @path ch15/15.4/15.4.4/15.4.4.17/15.4.4.17-7-c-ii-18.js
+ * @description Array.prototype.some - 'this' of 'callbackfn' is an String object when T is not an object (T is a string primitive)
  */
 
 
 function testcase() {
 
-        var accessed = false;
-
         function callbackfn(val, idx, obj) {
-            accessed = true;
-            return 'hello' === this.valueOf();
+            return this.valueOf() === "hello!";
         }
 
-        var obj = { 0: 11, length: 2 };
+        var obj = { 0: 11, 1: 9, length: 2 };
 
-        return Array.prototype.every.call(obj, callbackfn, "hello") && accessed;
+        return Array.prototype.some.call(obj, callbackfn, "hello!");
     }
 runTestCase(testcase);
