@@ -4,31 +4,29 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch15/15.4/15.4.4/15.4.4.22/15.4.4.22-9-c-i-8.js
- * @description Array.prototype.reduceRight - element to be retrieved is inherited data property on an Array
+ * @path ch15/15.4/15.4.4/15.4.4.18/15.4.4.18-7-c-i-8.js
+ * @description Array.prototype.forEach - element to be retrieved is inherited data property on an Array
  */
 
 
 function testcase() {
 
         var testResult = false;
-        function callbackfn(prevVal, curVal, idx, obj) {
+
+        function callbackfn(val, idx, obj) {
             if (idx === 1) {
-                testResult = (curVal === 1);
+                testResult = (val === 13);
             }
         }
 
         try {
-            Array.prototype[0] = 0;
-            Array.prototype[1] = 1;
-            Array.prototype[2] = 2;
-            [, , , ].reduceRight(callbackfn, "initialValue");
-            return testResult;
+            Array.prototype[1] = 13;
 
+            [, , , ].forEach(callbackfn);
+
+            return testResult;
         } finally {
-            delete Array.prototype[0];
             delete Array.prototype[1];
-            delete Array.prototype[2];
         }
     }
 runTestCase(testcase);
