@@ -4,8 +4,8 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch15/15.4/15.4.4/15.4.4.20/15.4.4.20-9-c-iii-1-3.js
- * @description Array.prototype.filter - value of returned array element can be enumerated
+ * @path ch15/15.4/15.4.4/15.4.4.20/15.4.4.20-9-c-iii-1-1.js
+ * @description Array.prototype.filter - value of returned array element equals to 'kValue'
  */
 
 
@@ -15,19 +15,9 @@ function testcase() {
             return true;
         }
 
-        var obj = { 0: 11, length: 2 };
+        var obj = { 0: 11, 1: 9, length: 2 };
         var newArr = Array.prototype.filter.call(obj, callbackfn);
 
-        var prop;
-        var enumerable = false;
-        for (prop in newArr) {
-            if (newArr.hasOwnProperty(prop)) {
-                if (prop === "0") {
-                    enumerable = true;
-                }
-            }
-        }
-
-        return enumerable;
+        return newArr[0] === obj[0] && newArr[1] === obj[1];
     }
 runTestCase(testcase);
