@@ -4,17 +4,18 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch15/15.4/15.4.4/15.4.4.17/15.4.4.17-7-c-iii-21.js
- * @description Array.prototype.some - return value of callbackfn is a Date object
+ * @path ch15/15.4/15.4.4/15.4.4.20/15.4.4.20-9-c-iii-21.js
+ * @description Array.prototype.filter - return value of callbackfn is the Math object
  */
 
 
 function testcase() {
 
         function callbackfn(val, idx, obj) {
-            return new Date();
+            return Math;
         }
 
-        return [11].some(callbackfn);
+        var newArr = [11].filter(callbackfn);
+        return newArr.length === 1 && newArr[0] === 11;
     }
 runTestCase(testcase);
