@@ -4,8 +4,8 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch15/15.4/15.4.4/15.4.4.22/15.4.4.22-8-b-iii-1-18.js
- * @description Array.prototype.reduceRight - element to be retrieved is own accessor property without a get function on an Array
+ * @path ch15/15.4/15.4.4/15.4.4.22/15.4.4.22-8-b-iii-1-29.js
+ * @description Array.prototype.reduceRight applied to Function object which implements its own property get method
  */
 
 
@@ -14,18 +14,19 @@ function testcase() {
         var testResult = false;
         function callbackfn(prevVal, curVal, idx, obj) {
             if (idx === 1) {
-                testResult = (typeof prevVal === "undefined");
+                testResult = (prevVal === 2);
             }
         }
 
-        var arr = [0, 1];
+        var obj = function (a, b, c) {
+            return a + b + c;
+        };
 
-        Object.defineProperty(arr, "2", {
-            set: function () { },
-            configurable: true
-        });
+        obj[0] = 0;
+        obj[1] = 1;
+        obj[2] = 2;
 
-        arr.reduceRight(callbackfn);
+        Array.prototype.reduceRight.call(obj, callbackfn);
         return testResult;
 
     }
